# pi_anwing_webthing
A web connected patio awnings controller on Raspberry Pi

Pololu TB6612FNG Dual Motortreiber Carrier

https://www.pololu.com/product/713


https://www.ebay.co.uk/itm/Gear-Motor-Direct-Current-6-12V-Electric-With-Removable-Crank-DGO-3512ADA-/183375290396